diff

Function diff 

pub fn diff(
    before: &SnapshotSignature,
    after: &SnapshotSignature,
) -> ActionEffect
Diff two signatures into an ActionEffect. Any of: URL change, title change, a changed set of interactable handles, or new console errors counts as a change. Identical signatures are a ActionEffect::NoOp.