pub struct LspConfig {
pub enabled: bool,
}Expand description
LSP integration configuration.
When present, language servers are spawned lazily after file-modifying tools and diagnostics are appended to tool output.
Fields
enabled: boolWhether LSP integration is enabled. Default: true when the section is present.