pub async fn load_glob(
kb: &dyn KnowledgeBase,
scope: &TenantScope,
pattern: &str,
config: &ChunkConfig,
) -> Result<usize, Error>Expand description
Load all files matching a glob pattern and index their chunks.
pub async fn load_glob(
kb: &dyn KnowledgeBase,
scope: &TenantScope,
pattern: &str,
config: &ChunkConfig,
) -> Result<usize, Error>Load all files matching a glob pattern and index their chunks.