pub struct PartialAgentConfig {Show 17 fields
pub system_prompt: Option<String>,
pub max_tokens: Option<u32>,
pub max_turns: Option<usize>,
pub tool_profile: Option<String>,
pub dangerous_tools: Option<bool>,
pub max_identical_tool_calls: Option<u32>,
pub max_fuzzy_identical_tool_calls: Option<u32>,
pub max_tool_calls_per_turn: Option<u32>,
pub reasoning_effort: Option<String>,
pub enable_reflection: Option<bool>,
pub tool_timeout_seconds: Option<u64>,
pub max_tool_output_bytes: Option<usize>,
pub run_timeout_seconds: Option<u64>,
pub tool_output_compression_threshold: Option<usize>,
pub max_tools_per_turn: Option<usize>,
pub response_cache_size: Option<usize>,
pub max_total_tokens: Option<u64>,
}Expand description
A partial agent config where all fields are optional. Used for template defaults that can be overridden by user config.
Fields
system_prompt: Option<String>max_tokens: Option<u32>max_turns: Option<usize>tool_profile: Option<String>dangerous_tools: Option<bool>max_identical_tool_calls: Option<u32>max_fuzzy_identical_tool_calls: Option<u32>max_tool_calls_per_turn: Option<u32>reasoning_effort: Option<String>enable_reflection: Option<bool>tool_timeout_seconds: Option<u64>max_tool_output_bytes: Option<usize>run_timeout_seconds: Option<u64>tool_output_compression_threshold: Option<usize>max_tools_per_turn: Option<usize>response_cache_size: Option<usize>max_total_tokens: Option<u64>Trait Implementations
Sourceimpl Clone for PartialAgentConfig
impl Clone for PartialAgentConfig
Sourcefn clone(&self) -> PartialAgentConfig
fn clone(&self) -> PartialAgentConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PartialAgentConfig
impl Debug for PartialAgentConfig
Sourceimpl Default for PartialAgentConfig
impl Default for PartialAgentConfig
Sourcefn default() -> PartialAgentConfig
fn default() -> PartialAgentConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PartialAgentConfig
impl<'de> Deserialize<'de> for PartialAgentConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more